#!/bin/sh
#
# source: http://valgrind.org/downloads/valgrind-3.4.1.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='valgrind'
softversion='3.4.1'
packageversion='60.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tar.bz2
rm -rf $dest

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in `find . -type l` ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/valgrind/html $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/valgrind/* $dest/usr/doc/$soft-$softversion
cp -a ACKNOWLEDGEMENTS AUTHORS COPYING FAQ.txt INSTALL NEWS README* $dest/usr/doc/$soft-$softversion
rm -rf $dest/usr/share
rm $dest/usr/doc/$soft-$softversion/${soft}_manual.ps

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC >> $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

        |-----handy-ruler------------------------------------------------------|
valgrind: valgrind - A tool for debugging and profiling Linux programs
valgrind:
valgrind: With Valgrind's tool suite you can automatically detect many memory
valgrind: management and threading bugs, avoiding hours of frustrating
valgrind: bug-hunting, making your programs more stable. You can also perform
valgrind: detailed profiling to help speed up your programs.
valgrind: The Valgrind distribution currently includes four tools: a memory
valgrind: error detector, a cache (time) profiler, a call-graph profiler, and
valgrind: a heap (space) profiler.
valgrind:
valgrind:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5